/*
 *  newalarmaction.cpp  -  menu action to select a new alarm type
 *  Program:  kalarm
 *  Copyright © 2007,2008 by David Jarvie <software@astrojar.org.uk>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "kalarm.h"
#include "newalarmaction.moc"

#include "shellprocess.h"

#include <kpopupmenu.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kstdaccel.h>
#include <kdebug.h>


bool NewAlarmAction::mLoaded = false;
static QIconSet displayIcon;
static QIconSet commandIcon;
static QIconSet mailIcon;


NewAlarmAction::NewAlarmAction(bool templates, const QString& label, QObject* parent, const char* name)
	: KActionMenu(label, "filenew", parent, name)
{
	setShortcut(KStdAccel::openNew());
	if (!mLoaded)
	{
		displayIcon = SmallIconSet("view_remove");
		commandIcon = SmallIconSet("exec");
		mailIcon    = SmallIconSet("mail_generic");
		mLoaded = true;
	}
	popupMenu()->insertItem(displayIcon, (templates ? i18n("&Display Alarm Template") : i18n("Display Alarm")), (int)EditAlarmDlg::DISPLAY);
	popupMenu()->insertItem(commandIcon, (templates ? i18n("&Command Alarm Template") : i18n("Command Alarm")), (int)EditAlarmDlg::COMMAND);
	popupMenu()->insertItem(mailIcon, (templates ? i18n("&Email Alarm Template") : i18n("Email Alarm")), (int)EditAlarmDlg::EMAIL);
	setDelayed(false);
	connect(popupMenu(), SIGNAL(aboutToShow()), SLOT(slotInitMenu()));
	connect(popupMenu(), SIGNAL(activated(int)), SLOT(slotSelected(int)));
}

/******************************************************************************
*  Called when the action is clicked.
*/
void NewAlarmAction::slotInitMenu()
{
	// Don't allow shell commands in kiosk mode
	popupMenu()->setItemEnabled(EditAlarmDlg::COMMAND, ShellProcess::authorised());
}

/******************************************************************************
*  Called when an alarm type is selected from the New popup menu.
*/
void NewAlarmAction::slotSelected(int id)
{
	emit selected(static_cast<EditAlarmDlg::Type>(id));
}
